@@ -29,7 +29,14 @@
 #define DEBUG_KP_EFFECT_REDUCE_COLORS 0
 
 
-#include <kpEffectReduceColorsWidget.h>
+#include "kpEffectReduceColorsWidget.h"
+
+#include "imagelib/effects/kpEffectReduceColors.h"
+#include "commands/imagelib/effects/kpEffectReduceColorsCommand.h"
+#include "pixmapfx/kpPixmapFX.h"
+
+#include <kdebug.h>
+#include <klocale.h>
 
 #include <qbitmap.h>
 #include <qbuttongroup.h>
@@ -39,21 +46,13 @@
 #include <qpixmap.h>
 #include <qradiobutton.h>
 
-#include <kdebug.h>
-#include <klocale.h>
-
-#include <kpEffectReduceColors.h>
-#include <kpEffectReduceColorsCommand.h>
-#include <kpPixmapFX.h>
-
 
 kpEffectReduceColorsWidget::kpEffectReduceColorsWidget (bool actOnSelection,
                                                         QWidget *parent)
     : kpEffectWidgetBase (actOnSelection, parent)
 {
     QVBoxLayout *lay = new QVBoxLayout (this);
-    lay->setSpacing(spacingHint ());
-    lay->setMargin(marginHint ());
+    lay->setMargin (0);
 
 
     m_blackAndWhiteRadioButton =
@@ -174,4 +173,3 @@ kpEffectCommandBase *kpEffectReduceColorsWidget::createCommand (
 
 //---------------------------------------------------------------------
 
-#include <kpEffectReduceColorsWidget.moc>
